@@ -22,18 +22,17 @@ from loguru import logger
 import requests
 import typing
 import time
+import psutil
 
 __PROJECT_NAME__ = r"cort_client"
 __AUTHOR__ = r"williamfzc"
 __AUTHOR_EMAIL__ = r"fengzc@vip.qq.com"
 __LICENSE__ = r"MIT"
-__VERSION__ = r"0.1.1"
+__VERSION__ = r"0.1.2"
 
 
 class CortJob(object):
-    def __init__(
-        self, product_name: str, user_name: str, cli: "CortClient", *_, **__,
-    ):
+    def __init__(self, product_name: str, user_name: str, cli: "CortClient", *_, **__):
         self.product_name = product_name
         self.user_name = user_name
 
@@ -60,7 +59,7 @@ class CortJob(object):
     def get_hash_name(self) -> str:
         raise NotImplementedError
 
-    def start(self):
+    def start(self) -> psutil.Process:
         command = [
             "am",
             "instrument",
@@ -118,7 +117,8 @@ class CortJob(object):
             f"{self.package_name}.test/{self.package_name}.CortTestRunner",
         ]
         logger.debug(f"job start with command: {command}")
-        self.device.shell(command)
+        process = self.device.shell(command, no_wait=True)
+        return psutil.Process(process.pid)
         # todo: test will never stop by default. need a cleanup here
 
 
@@ -126,10 +126,7 @@ class CortAPI(object):
     METHOD_GET = "GET"
     METHOD_POST = "POST"
 
-    _METHOD_MAP = {
-        METHOD_GET: requests.get,
-        METHOD_POST: requests.post,
-    }
+    _METHOD_MAP = {METHOD_GET: requests.get, METHOD_POST: requests.post}
     # fill these
     method_name: typing.Union[METHOD_GET, METHOD_POST]
     path: str
